<?php

/**
 * Filter to restrict login to user accounts affiliated with the target SP only
 *
 * Based on expirycheck module
 *
 * <code>
 * // show about2xpire warning or deny access if netid is expired
 * 10 => array(
 *     'class' => 'restrictLogin:RestrictLogin',
 *     'sp_entityid_attr' => 'associatedSP',
  * ),
 * </code>
 *
 * @author Olivier Salaün, RENATER. <olivier.salaun@renater.fr>
 * @package simpleSAMLphp
 * @version $Id$
 */

class sspmod_restrictLogin_Auth_Process_RestrictLogin extends SimpleSAML_Auth_ProcessingFilter {

	private $sp_entityid_attr = NULL;


	/**
	 * Initialize this filter.
	 *
	 * @param array $config  Configuration information about this filter.
	 * @param mixed $reserved  For future use.
	 */
	public function __construct($config, $reserved) {
		parent::__construct($config, $reserved);

		assert('is_array($config)');
		assert('array_key_exists("sp_entityid_attr", $config)');

		if (array_key_exists('sp_entityid_attr', $config)) {
			$this->sp_entityid_attr = $config['sp_entityid_attr'];
			if (!is_string($this->sp_entityid_attr)) {
				throw new Exception('Invalid attribute name given as sp_entityid_attr to restrictLogin:RestrictLogin filter.');
			}
		}
	}

	/**
	 * Apply filter
	 *
	 * @param array &$state  The current state.
	 */
	public function process(&$state) {

		assert('is_array($state)');
		assert('array_key_exists("Destination", $state)');
		assert('array_key_exists("entityid", $state["Destination"])');

		$sp_entityid_attr = $state['Attributes'][$this->sp_entityid_attr][0];

		if ($state['Destination']['entityid'] !== $sp_entityid_attr) {
			if (isset($state['isPassive']) && $state['isPassive'] === TRUE) {
				/* We have a passive request. Skip the warning. */
				return;
			}

			SimpleSAML_Logger::warning('restrictLogin: user '.$state['Attributes']['uid'][0].' cannot be used to access '.$state['Destination']['entityid']);
			/* Save state and redirect. */
			$state['destination_sp_entityid'] = $state['Destination']['entityid'];
			$state['associated_sp_entityid'] = $sp_entityid_attr;
			$id = SimpleSAML_Auth_State::saveState($state, 'restrictLogin:RestrictLogin');
			$url = SimpleSAML_Module::getModuleURL('restrictLogin/logindenied.php');
			SimpleSAML_Utilities::redirectTrustedURL($url, array('StateId' => $id));
		}

	}


}


?>
